Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(521)

Unified Diff: talk/app/webrtc/statscollector.cc

Issue 1312643004: Replaces SSLIdentity* with scoped_refptr<RTCCertificate> in cricket::Transport layer. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | talk/app/webrtc/statscollector_unittest.cc » ('j') | webrtc/p2p/base/dtlstransport.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: talk/app/webrtc/statscollector.cc
diff --git a/talk/app/webrtc/statscollector.cc b/talk/app/webrtc/statscollector.cc
index ad64639eb93a18f04295499712163f49331080af..eb32356400509078353c306a2a47e37f88051a09 100644
--- a/talk/app/webrtc/statscollector.cc
+++ b/talk/app/webrtc/statscollector.cc
@@ -692,7 +692,7 @@ void StatsCollector::ExtractSessionInfo() {
// expose them in stats reports. All channels in a transport share the
// same local and remote certificates.
//
// Note that Transport::GetIdentity and Transport::GetRemoteCertificate
// invoke method calls on the worker thread and block this thread, but
// messages are still processed on this thread, which may blow way the
// existing transports. So we cannot reuse |transport| after these calls.
@@ -700,9 +700,9 @@ void StatsCollector::ExtractSessionInfo() {
cricket::Transport* transport =
session_->GetTransport(transport_iter.second.content_name);
- rtc::scoped_ptr<rtc::SSLIdentity> identity;
- if (transport && transport->GetIdentity(identity.accept())) {
- StatsReport* r = AddCertificateReports(&(identity->certificate()));
+ rtc::scoped_refptr<rtc::RTCCertificate> certificate;
+ if (transport && transport->GetCertificate(&certificate)) {
+ StatsReport* r = AddCertificateReports(&(certificate->ssl_certificate()));
if (r)
local_cert_report_id = r->id();
}
@@ -692,7 +692,7 @@ void StatsCollector::ExtractSessionInfo() {
// same local and remote certificates.
//
- // Note that Transport::GetIdentity and Transport::GetRemoteCertificate
+ // Note that Transport::GetCertificate and Transport::GetRemoteCertificate
// invoke method calls on the worker thread and block this thread, but
// messages are still processed on this thread, which may blow way the
« no previous file with comments | « no previous file | talk/app/webrtc/statscollector_unittest.cc » ('j') | webrtc/p2p/base/dtlstransport.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698